#ifndef _HEXAGON_NN_DOMAINS_STUB_H
#define _HEXAGON_NN_DOMAINS_STUB_H
#include "hexagon_nn.h"
#ifndef _QAIC_ENV_H
#define _QAIC_ENV_H

#ifdef __GNUC__
#ifdef __clang__
#pragma GCC diagnostic ignored "-Wunknown-pragmas"
#else
#pragma GCC diagnostic ignored "-Wpragmas"
#endif
#pragma GCC diagnostic ignored "-Wuninitialized"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#pragma GCC diagnostic ignored "-Wunused-function"
#endif

#ifndef _ATTRIBUTE_UNUSED

#ifdef _WIN32
#define _ATTRIBUTE_UNUSED
#else
#define _ATTRIBUTE_UNUSED __attribute__ ((unused))
#endif

#endif // _ATTRIBUTE_UNUSED

#ifndef __QAIC_REMOTE
#define __QAIC_REMOTE(ff) ff
#endif //__QAIC_REMOTE

#ifndef __QAIC_HEADER
#define __QAIC_HEADER(ff) ff
#endif //__QAIC_HEADER

#ifndef __QAIC_HEADER_EXPORT
#define __QAIC_HEADER_EXPORT
#endif // __QAIC_HEADER_EXPORT

#ifndef __QAIC_HEADER_ATTRIBUTE
#define __QAIC_HEADER_ATTRIBUTE
#endif // __QAIC_HEADER_ATTRIBUTE

#ifndef __QAIC_IMPL
#define __QAIC_IMPL(ff) ff
#endif //__QAIC_IMPL

#ifndef __QAIC_IMPL_EXPORT
#define __QAIC_IMPL_EXPORT
#endif // __QAIC_IMPL_EXPORT

#ifndef __QAIC_IMPL_ATTRIBUTE
#define __QAIC_IMPL_ATTRIBUTE
#endif // __QAIC_IMPL_ATTRIBUTE

#ifndef __QAIC_STUB
#define __QAIC_STUB(ff) ff
#endif //__QAIC_STUB

#ifndef __QAIC_STUB_EXPORT
#define __QAIC_STUB_EXPORT
#endif // __QAIC_STUB_EXPORT

#ifndef __QAIC_STUB_ATTRIBUTE
#define __QAIC_STUB_ATTRIBUTE
#endif // __QAIC_STUB_ATTRIBUTE

#ifndef __QAIC_SKEL
#define __QAIC_SKEL(ff) ff
#endif //__QAIC_SKEL__

#ifndef __QAIC_SKEL_EXPORT
#define __QAIC_SKEL_EXPORT
#endif // __QAIC_SKEL_EXPORT

#ifndef __QAIC_SKEL_ATTRIBUTE
#define __QAIC_SKEL_ATTRIBUTE
#endif // __QAIC_SKEL_ATTRIBUTE

#ifdef __QAIC_DEBUG__
   #ifndef __QAIC_DBG_PRINTF__
   #include <stdio.h>
   #define __QAIC_DBG_PRINTF__( ee ) do { printf ee ; } while(0)
   #endif
#else
   #define __QAIC_DBG_PRINTF__( ee ) (void)0
#endif


#define _OFFSET(src, sof)  ((void*)(((char*)(src)) + (sof)))

#define _COPY(dst, dof, src, sof, sz)  \
   do {\
         struct __copy { \
            char ar[sz]; \
         };\
         *(struct __copy*)_OFFSET(dst, dof) = *(struct __copy*)_OFFSET(src, sof);\
   } while (0)

#define _COPYIF(dst, dof, src, sof, sz)  \
   do {\
      if(_OFFSET(dst, dof) != _OFFSET(src, sof)) {\
         _COPY(dst, dof, src, sof, sz); \
      } \
   } while (0)

_ATTRIBUTE_UNUSED
static __inline void _qaic_memmove(void* dst, void* src, int size) {
   int i;
   for(i = 0; i < size; ++i) {
      ((char*)dst)[i] = ((char*)src)[i];
   }
}

#define _MEMMOVEIF(dst, src, sz)  \
   do {\
      if(dst != src) {\
         _qaic_memmove(dst, src, sz);\
      } \
   } while (0)


#define _ASSIGN(dst, src, sof)  \
   do {\
      dst = OFFSET(src, sof); \
   } while (0)

#define _STD_STRLEN_IF(str) (str == 0 ? 0 : strlen(str))

#include "AEEStdErr.h"

#define _TRY(ee, func) \
   do { \
      if (AEE_SUCCESS != ((ee) = func)) {\
         __QAIC_DBG_PRINTF__((__FILE__ ":%d:error:%d:%s\n", __LINE__, (int)(ee),#func));\
         goto ee##bail;\
      } \
   } while (0)

#define _CATCH(exception) exception##bail: if (exception != AEE_SUCCESS)

#define _ASSERT(nErr, ff) _TRY(nErr, 0 == (ff) ? AEE_EBADPARM : AEE_SUCCESS)

#ifdef __QAIC_DEBUG__
#define _ALLOCATE(nErr, pal, size, alignment, pv) _TRY(nErr, _allocator_alloc(pal, __FILE_LINE__, size, alignment, (void**)&pv));\
                                                  _ASSERT(nErr,pv || !(size))   
#else
#define _ALLOCATE(nErr, pal, size, alignment, pv) _TRY(nErr, _allocator_alloc(pal, 0, size, alignment, (void**)&pv));\
                                                  _ASSERT(nErr,pv || !(size))
#endif


#endif // _QAIC_ENV_H

#include "remote.h"
#include <string.h>
#ifndef _ALLOCATOR_H
#define _ALLOCATOR_H

#include <stdlib.h>
#include <stdint.h>

typedef struct _heap _heap;
struct _heap {
   _heap* pPrev;
   const char* loc;
   uint64_t buf;
};

typedef struct _allocator {
   _heap* pheap;
   uint8_t* stack;
   uint8_t* stackEnd;
   int nSize;
} _allocator;

_ATTRIBUTE_UNUSED
static __inline int _heap_alloc(_heap** ppa, const char* loc, int size, void** ppbuf) {
   _heap* pn = 0;
   pn = malloc(size + sizeof(_heap) - sizeof(uint64_t));
   if(pn != 0) {
      pn->pPrev = *ppa;
      pn->loc = loc;
      *ppa = pn;
      *ppbuf = (void*)&(pn->buf);
      return 0;
   } else {
      return -1;
   }
}
#define _ALIGN_SIZE(x, y) (((x) + (y-1)) & ~(y-1))

_ATTRIBUTE_UNUSED
static __inline int _allocator_alloc(_allocator* me,
                                    const char* loc,
                                    int size,
                                    unsigned int al,
                                    void** ppbuf) {
   if(size < 0) {
      return -1;
   } else if (size == 0) {
      *ppbuf = 0;
      return 0;
   }
   if((_ALIGN_SIZE((uintptr_t)me->stackEnd, al) + size) < (uintptr_t)me->stack + me->nSize) {
      *ppbuf = (uint8_t*)_ALIGN_SIZE((uintptr_t)me->stackEnd, al);
      me->stackEnd = (uint8_t*)_ALIGN_SIZE((uintptr_t)me->stackEnd, al) + size;
      return 0;
   } else {
      return _heap_alloc(&me->pheap, loc, size, ppbuf);
   }
}

_ATTRIBUTE_UNUSED
static __inline void _allocator_deinit(_allocator* me) {
   _heap* pa = me->pheap;
   while(pa != 0) {
      _heap* pn = pa;
      const char* loc = pn->loc;
      (void)loc;
      pa = pn->pPrev;
      free(pn);
   }
}

_ATTRIBUTE_UNUSED
static __inline void _allocator_init(_allocator* me, uint8_t* stack, int stackSize) {
   me->stack =  stack;
   me->stackEnd =  stack + stackSize;
   me->nSize = stackSize;
   me->pheap = 0;
}


#endif // _ALLOCATOR_H

#ifndef SLIM_H
#define SLIM_H

#include <stdint.h>

//a C data structure for the idl types that can be used to implement
//static and dynamic language bindings fairly efficiently.
//
//the goal is to have a minimal ROM and RAM footprint and without
//doing too many allocations.  A good way to package these things seemed
//like the module boundary, so all the idls within  one module can share
//all the type references.


#define PARAMETER_IN       0x0
#define PARAMETER_OUT      0x1
#define PARAMETER_INOUT    0x2
#define PARAMETER_ROUT     0x3
#define PARAMETER_INROUT   0x4

//the types that we get from idl
#define TYPE_OBJECT             0x0
#define TYPE_INTERFACE          0x1
#define TYPE_PRIMITIVE          0x2
#define TYPE_ENUM               0x3
#define TYPE_STRING             0x4
#define TYPE_WSTRING            0x5
#define TYPE_STRUCTURE          0x6
#define TYPE_UNION              0x7
#define TYPE_ARRAY              0x8
#define TYPE_SEQUENCE           0x9

//these require the pack/unpack to recurse
//so it's a hint to those languages that can optimize in cases where
//recursion isn't necessary.
#define TYPE_COMPLEX_STRUCTURE  (0x10 | TYPE_STRUCTURE)
#define TYPE_COMPLEX_UNION      (0x10 | TYPE_UNION)
#define TYPE_COMPLEX_ARRAY      (0x10 | TYPE_ARRAY)
#define TYPE_COMPLEX_SEQUENCE   (0x10 | TYPE_SEQUENCE)


typedef struct Type Type;

#define INHERIT_TYPE\
   int32_t nativeSize;                /*in the simple case its the same as wire size and alignment*/\
   union {\
      struct {\
         const uintptr_t         p1;\
         const uintptr_t         p2;\
      } _cast;\
      struct {\
         uint32_t  iid;\
         uint32_t  bNotNil;\
      } object;\
      struct {\
         const Type  *arrayType;\
         int32_t      nItems;\
      } array;\
      struct {\
         const Type *seqType;\
         int32_t      nMaxLen;\
      } seqSimple; \
      struct {\
         uint32_t bFloating;\
         uint32_t bSigned;\
      } prim; \
      const SequenceType* seqComplex;\
      const UnionType  *unionType;\
      const StructType *structType;\
      int32_t         stringMaxLen;\
      uint8_t        bInterfaceNotNil;\
   } param;\
   uint8_t    type;\
   uint8_t    nativeAlignment\

typedef struct UnionType UnionType;
typedef struct StructType StructType;
typedef struct SequenceType SequenceType;
struct Type {
   INHERIT_TYPE;
};

struct SequenceType {
   const Type *         seqType;
   uint32_t               nMaxLen;
   uint32_t               inSize;
   uint32_t               routSizePrimIn;
   uint32_t               routSizePrimROut;
};

//byte offset from the start of the case values for
//this unions case value array.  it MUST be aligned
//at the alignment requrements for the descriptor
//
//if negative it means that the unions cases are
//simple enumerators, so the value read from the descriptor
//can be used directly to find the correct case
typedef union CaseValuePtr CaseValuePtr;
union CaseValuePtr {
   const uint8_t*   value8s;
   const uint16_t*  value16s;
   const uint32_t*  value32s;
   const uint64_t*  value64s;
};

//these are only used in complex cases
//so I pulled them out of the type definition as references to make
//the type smaller
struct UnionType {
   const Type           *descriptor;
   uint32_t               nCases;
   const CaseValuePtr   caseValues;
   const Type * const   *cases;
   int32_t               inSize;
   int32_t               routSizePrimIn;
   int32_t               routSizePrimROut;
   uint8_t                inAlignment;
   uint8_t                routAlignmentPrimIn;
   uint8_t                routAlignmentPrimROut;
   uint8_t                inCaseAlignment;
   uint8_t                routCaseAlignmentPrimIn;
   uint8_t                routCaseAlignmentPrimROut;
   uint8_t                nativeCaseAlignment;
   uint8_t              bDefaultCase;
};

struct StructType {
   uint32_t               nMembers;
   const Type * const   *members;
   int32_t               inSize;
   int32_t               routSizePrimIn;
   int32_t               routSizePrimROut;
   uint8_t                inAlignment;
   uint8_t                routAlignmentPrimIn;
   uint8_t                routAlignmentPrimROut;
};

typedef struct Parameter Parameter;
struct Parameter {
   INHERIT_TYPE;
   uint8_t    mode;
   uint8_t  bNotNil;
};

#define SLIM_IFPTR32(is32,is64) (sizeof(uintptr_t) == 4 ? (is32) : (is64))
#define SLIM_SCALARS_IS_DYNAMIC(u) (((u) & 0x00ffffff) == 0x00ffffff)

typedef struct Method Method;
struct Method {
   uint32_t                    uScalars;            //no method index
   int32_t                     primInSize;
   int32_t                     primROutSize;
   int                         maxArgs;
   int                         numParams;
   const Parameter * const     *params;
   uint8_t                       primInAlignment;
   uint8_t                       primROutAlignment;
};

typedef struct Interface Interface;

struct Interface {
   int                            nMethods;
   const Method  * const          *methodArray;
   int                            nIIds;
   const uint32_t                   *iids;
   const uint16_t*                  methodStringArray;
   const uint16_t*                  methodStrings;
   const char*                    strings;
};


#endif //SLIM_H


#ifndef _HEXAGON_NN_DOMAINS_SLIM_H
#define _HEXAGON_NN_DOMAINS_SLIM_H
#include "remote.h"
#include <stdint.h>

#ifndef __QAIC_SLIM
#define __QAIC_SLIM(ff) ff
#endif
#ifndef __QAIC_SLIM_EXPORT
#define __QAIC_SLIM_EXPORT
#endif

static const Type types[16];
static const Type* const typeArrays[19] = {&(types[1]),&(types[1]),&(types[1]),&(types[1]),&(types[13]),&(types[1]),&(types[1]),&(types[1]),&(types[8]),&(types[1]),&(types[9]),&(types[10]),&(types[14]),&(types[13]),&(types[1]),&(types[1]),&(types[3]),&(types[9]),&(types[9])};
static const StructType structTypes[8] = {{0x3,&(typeArrays[12]),0xc,0x4,0x8,0x4,0x4,0x4},{0x2,&(typeArrays[17]),0x8,0x0,0x8,0x4,0x1,0x4},{0x2,&(typeArrays[0]),0x8,0x0,0x8,0x4,0x1,0x4},{0x2,&(typeArrays[15]),0x104,0x0,0x104,0x4,0x1,0x4},{0x5,&(typeArrays[7]),0x30,0x0,0x30,0x4,0x1,0x4},{0x4,&(typeArrays[0]),0x10,0x0,0x10,0x4,0x1,0x4},{0x7,&(typeArrays[0]),0x1c,0x4,0x18,0x4,0x4,0x4},{0x2,&(typeArrays[3]),0x8,0x4,0x4,0x4,0x4,0x4}};
static const SequenceType sequenceTypes[2] = {{&(types[12]),0x0,0x1c,0x4,0x18},{&(types[15]),0x0,0x8,0x4,0x4}};
static const Type types[16] = {{0x8,{{(const uintptr_t)&(structTypes[2]),0}}, 6,0x4},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4},{0x104,{{(const uintptr_t)&(structTypes[3]),0}}, 6,0x4},{0x100,{{(const uintptr_t)&(types[4]),(const uintptr_t)0x100}}, 8,0x1},{0x1,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x1},{0x1,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x1},{0x8,{{(const uintptr_t)&(structTypes[2]),0}}, 6,0x4},{0x30,{{(const uintptr_t)&(structTypes[4]),0}}, 6,0x4},{0x20,{{(const uintptr_t)&(types[1]),(const uintptr_t)0x8}}, 8,0x4},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4},{0x10,{{(const uintptr_t)&(structTypes[5]),0}}, 6,0x4},{SLIM_IFPTR32(0x20,0x28),{{(const uintptr_t)&(structTypes[6]),0}}, 22,SLIM_IFPTR32(0x4,0x8)},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[5]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8)},{0x4,{{0,0}}, 3,0x4},{SLIM_IFPTR32(0xc,0x18),{{(const uintptr_t)&(structTypes[7]),0}}, 22,SLIM_IFPTR32(0x4,0x8)}};
static const Parameter parameters[30] = {{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)0x0,0}}, 4,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x4,0x8),{{(const uintptr_t)0xdeadc0de,(const uintptr_t)0}}, 0,SLIM_IFPTR32(0x4,0x8),3,0},{SLIM_IFPTR32(0x4,0x8),{{(const uintptr_t)0xdeadc0de,(const uintptr_t)0}}, 0,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[0]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[2]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,0,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,3,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,3,0},{0x4,{{0,0}}, 3,0x4,3,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,0,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,3,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[5]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),4,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,0,0},{0x4,{{0,0}}, 3,0x4,0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[6]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[7]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[4]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[5]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[5]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),3,0},{0x4,{{0,0}}, 3,0x4,0,0},{0x4,{{0,0}}, 3,0x4,0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(types[11]),(const uintptr_t)0x0}}, 9,SLIM_IFPTR32(0x4,0x8),3,0},{0x4,{{(const uintptr_t)0,(const uintptr_t)1}}, 2,0x4,3,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)0x0,0}}, 4,SLIM_IFPTR32(0x4,0x8),3,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(sequenceTypes[0]),0}}, 25,SLIM_IFPTR32(0x4,0x8),0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(sequenceTypes[0]),0}}, 25,SLIM_IFPTR32(0x4,0x8),3,0},{SLIM_IFPTR32(0x10,0x18),{{(const uintptr_t)&(structTypes[0]),0}}, 22,SLIM_IFPTR32(0x4,0x8),3,0},{0x8,{{(const uintptr_t)&(structTypes[1]),0}}, 6,0x4,0,0},{SLIM_IFPTR32(0x8,0x10),{{(const uintptr_t)&(sequenceTypes[1]),0}}, 25,SLIM_IFPTR32(0x4,0x8),0,0}};
static const Parameter* const parameterArrays[115] = {(&(parameters[5])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[18])),(&(parameters[6])),(&(parameters[6])),(&(parameters[6])),(&(parameters[6])),(&(parameters[19])),(&(parameters[6])),(&(parameters[5])),(&(parameters[13])),(&(parameters[11])),(&(parameters[6])),(&(parameters[6])),(&(parameters[6])),(&(parameters[6])),(&(parameters[19])),(&(parameters[6])),(&(parameters[5])),(&(parameters[13])),(&(parameters[11])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[18])),(&(parameters[5])),(&(parameters[13])),(&(parameters[0])),(&(parameters[0])),(&(parameters[17])),(&(parameters[15])),(&(parameters[16])),(&(parameters[8])),(&(parameters[5])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[5])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[13])),(&(parameters[18])),(&(parameters[5])),(&(parameters[13])),(&(parameters[13])),(&(parameters[14])),(&(parameters[15])),(&(parameters[16])),(&(parameters[5])),(&(parameters[25])),(&(parameters[26])),(&(parameters[27])),(&(parameters[29])),(&(parameters[5])),(&(parameters[13])),(&(parameters[11])),(&(parameters[18])),(&(parameters[5])),(&(parameters[13])),(&(parameters[18])),(&(parameters[13])),(&(parameters[18])),(&(parameters[10])),(&(parameters[6])),(&(parameters[5])),(&(parameters[19])),(&(parameters[6])),(&(parameters[5])),(&(parameters[0])),(&(parameters[11])),(&(parameters[5])),(&(parameters[5])),(&(parameters[6])),(&(parameters[5])),(&(parameters[6])),(&(parameters[6])),(&(parameters[5])),(&(parameters[22])),(&(parameters[6])),(&(parameters[20])),(&(parameters[21])),(&(parameters[13])),(&(parameters[0])),(&(parameters[7])),(&(parameters[8])),(&(parameters[5])),(&(parameters[3])),(&(parameters[4])),(&(parameters[5])),(&(parameters[18])),(&(parameters[10])),(&(parameters[28])),(&(parameters[13])),(&(parameters[24])),(&(parameters[0])),(&(parameters[6])),(&(parameters[5])),(&(parameters[12])),(&(parameters[5])),(&(parameters[11])),(&(parameters[9])),(&(parameters[8])),(&(parameters[0])),(&(parameters[1])),(&(parameters[23])),(&(parameters[2]))};
static const Method methods[42] = {{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x1),0x4,0x0,2,2,(&(parameterArrays[111])),0x4,0x1},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x0,0x1,0x0),0x0,0x0,1,1,(&(parameterArrays[114])),0x1,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x0,0x0,0x0),0x0,0x0,0,0,0,0x0,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x3,0x0,0x0,0x0),0x8,0x0,4,2,(&(parameterArrays[95])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x3,0x0,0x0,0x0),0xc,0x0,5,3,(&(parameterArrays[94])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x1,0x0,0x0),0x0,0x8,2,2,(&(parameterArrays[6])),0x1,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x1,0x0,0x0),0x4,0x8,3,3,(&(parameterArrays[91])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x4,0x4,2,2,(&(parameterArrays[109])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x1,0x0,0x0),0x0,0x4,1,1,(&(parameterArrays[36])),0x1,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x1,0x0,0x0),0x0,0x4,1,1,(&(parameterArrays[71])),0x1,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x8,0x0,2,2,(&(parameterArrays[107])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x1,0x0,0x0),0xc,0x0,4,2,(&(parameterArrays[105])),0x4,0x1},{REMOTE_SCALARS_MAKEX(0,0,0x3,0x0,0x0,0x0),0x18,0x0,8,6,(&(parameterArrays[51])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x6,0x1,0x0,0x0),0x1c,0x4,11,8,(&(parameterArrays[29])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x1c,0x0,8,7,(&(parameterArrays[44])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x1c,0x0,7,7,(&(parameterArrays[37])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x10,0x0,5,4,(&(parameterArrays[66])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x4,0x0,1,1,(&(parameterArrays[0])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x2,0x0,0x0),0x1c,0x14,15,12,(&(parameterArrays[0])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x2,0x0,0x0),0x10,0x14,11,9,(&(parameterArrays[12])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x20,0x0,9,8,(&(parameterArrays[21])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x10,0x0,5,4,(&(parameterArrays[62])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x4,0x0,1,1,(&(parameterArrays[1])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0xc,0x0,3,3,(&(parameterArrays[88])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x2,0x0,0x0),0x8,0x4,5,3,(&(parameterArrays[85])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x8,0x0,2,2,(&(parameterArrays[0])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x4,0x8,3,3,(&(parameterArrays[82])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x0,0x1,0x0,0x0),0x0,0x4,1,1,(&(parameterArrays[113])),0x1,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x1,0x0,0x0),0x4,0x4,2,2,(&(parameterArrays[103])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x8,0x0,4,2,(&(parameterArrays[101])),0x4,0x1},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x4,0x4,2,2,(&(parameterArrays[80])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x4,0x0,2,1,(&(parameterArrays[5])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,255,255,15,15),0xc,0x0,6,3,(&(parameterArrays[57])),0x4,0x1},{REMOTE_SCALARS_MAKEX(0,0,255,255,15,15),0x10,0x8,7,4,(&(parameterArrays[57])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x8,0x4,2,2,(&(parameterArrays[99])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x1,0x0,0x0),0x8,0x4,3,3,(&(parameterArrays[79])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x0,0x0,0x0),0x4,0x0,1,1,(&(parameterArrays[14])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0xc,0x0,3,3,(&(parameterArrays[76])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x0,0x0,0x0),0x8,0x0,3,2,(&(parameterArrays[97])),0x4,0x0},{REMOTE_SCALARS_MAKEX(0,0,0x1,0x2,0x0,0x0),0x8,0x4,5,3,(&(parameterArrays[73])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,0x2,0x1,0x0,0x0),0x4,0x8,4,3,(&(parameterArrays[70])),0x4,0x4},{REMOTE_SCALARS_MAKEX(0,0,255,255,15,15),0x14,0x8,9,5,(&(parameterArrays[57])),0x4,0x4}};
static const Method* const methodArrays[48] = {&(methods[0]),&(methods[1]),&(methods[2]),&(methods[3]),&(methods[4]),&(methods[5]),&(methods[6]),&(methods[7]),&(methods[8]),&(methods[9]),&(methods[10]),&(methods[11]),&(methods[11]),&(methods[12]),&(methods[13]),&(methods[14]),&(methods[15]),&(methods[16]),&(methods[17]),&(methods[18]),&(methods[17]),&(methods[19]),&(methods[20]),&(methods[21]),&(methods[22]),&(methods[23]),&(methods[24]),&(methods[25]),&(methods[26]),&(methods[27]),&(methods[28]),&(methods[29]),&(methods[30]),&(methods[2]),&(methods[27]),&(methods[31]),&(methods[32]),&(methods[33]),&(methods[34]),&(methods[35]),&(methods[26]),&(methods[36]),&(methods[37]),&(methods[38]),&(methods[26]),&(methods[39]),&(methods[40]),&(methods[41])};
static const char strings[1454] = "serialized_obj_size_out\0GetHexagonBinaryVersion\0append_empty_const_node\0flattened_static_params\0free_udo_individual_lib\0udo_lib_registration_id\0multi_execution_cycles\0get_num_nodes_in_graph\0last_execution_cycles\0set_powersave_details\0execute_with_option\0set_powersave_level\0variable_write_flat\0populate_const_node\0config_with_options\0fastrpc_shell_addr\0extraInfoValidLen\0execute_with_info\0append_const_node\0set_graph_option\0register_udo_lib\0append_udo_node\0set_debug_level\0libhexagon_addr\0serialize_size\0populate_graph\0cpuEarlyWakeup\0init_with_info\0data_valid_len\0reset_perfinfo\0variable_write\0get_dsp_offset\0string_options\0new_graph_out\0op_id_to_name\0op_name_to_id\0variable_read\0target_offset\0free_udo_libs\0get_nodetype\0execute_info\0disable_dcvs\0get_perfinfo\0output_index\0data_len_out\0package_name\0so_path_name\0graph_config\0uint_options\0deserialize\0return_code\0execute_new\0batches_out\0zero_offset\0elementsize\0append_node\0string_data\0option_ptr\0in_options\0graph_data\0counter_hi\0counter_lo\0executions\0height_out\0batches_in\0output_idx\0uint_value\0get_power\0node_type\0extraInfo\0num_nodes\0cycles_hi\0cycles_lo\0depth_out\0width_out\0height_in\0max_sizes\0operation\0option_id\0graph_id\0priority\0PrintLog\0info_out\0teardown\0data_out\0depth_in\0width_in\0stepsize\0snpprint\0version\0n_items\0latency\0data_in\0execute\0prepare\0batches\0op_type\0outputs\0padding\0node_id\0buffer\0result\0unused\0corner\0height\0src_id\0inputs\0getlog\0event\0depth\0width\0close\0rank\0init\0open\0ver\0buf\0err\0uri\0";
static const uint16_t methodStrings[272] = {234,141,1384,1302,1370,1410,1404,929,549,1356,1318,1302,1370,1410,1404,929,549,1356,721,1349,1064,353,945,1154,934,371,141,1384,1302,1370,1410,1404,929,549,1356,1318,1302,1370,1410,1404,929,549,1356,721,1349,1064,353,862,141,1384,1302,1370,1410,1404,929,549,1356,1318,1302,1370,1410,1404,929,549,1356,441,141,1334,786,1310,72,1384,1377,1022,1318,1422,1134,898,886,1236,1445,910,141,1334,1144,1326,1384,1377,1022,1318,1422,1134,898,886,1236,1286,141,1011,1124,1227,1218,1278,874,1000,1114,1104,1209,773,666,141,1334,760,874,1000,1114,1104,1209,773,579,141,1334,760,1302,1370,1410,1404,1278,747,141,1191,1334,989,978,967,1262,48,141,1334,1302,1370,1410,1404,499,389,141,1334,1302,1370,1410,1404,929,812,141,825,1154,1033,609,1154,922,314,825,1154,1033,609,1154,922,534,823,384,1173,519,274,141,1334,760,1278,294,141,1334,929,680,838,1342,624,850,840,141,1342,850,489,141,0,850,407,141,647,1038,144,141,1094,1084,708,1164,1334,1054,190,141,1094,1084,212,1363,742,1270,424,799,120,1445,504,141,956,167,141,1074,638,1334,647,652,647,1334,564,141,1398,1391,141,1441,1245,141,1441,457,141,268,96,120,1445,594,473,334,1432,1449,188,1044,716,1182,1441,24,1437,1254,1437,254,268,1200,141,1294,141,1427,823,694,1445,1416,188,734,818};
static const uint16_t methodStringsArrays[48] = {247,268,271,159,151,244,213,241,266,264,238,235,232,81,65,143,135,176,262,95,260,108,118,171,258,209,127,229,205,256,226,223,220,270,254,252,47,25,166,201,197,250,193,217,189,185,181,0};
__QAIC_SLIM_EXPORT const Interface __QAIC_SLIM(hexagon_nn_domains_slim) = {48,&(methodArrays[0]),0,0,&(methodStringsArrays [0]),methodStrings,strings};
#endif //_HEXAGON_NN_DOMAINS_SLIM_H
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_skel_handle_invoke)(remote_handle64 _h, uint32_t _sc, remote_arg* _pra) __QAIC_STUB_ATTRIBUTE {
   return __QAIC_REMOTE(remote_handle64_invoke)(_h, _sc, _pra);
}
#ifdef __cplusplus
extern "C" {
#endif
extern int remote_register_dma_handle(int, uint32_t);
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_open)(const char* uri, remote_handle64* h) __QAIC_STUB_ATTRIBUTE {
   return __QAIC_REMOTE(remote_handle64_open)(uri, h);
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_close)(remote_handle64 h) __QAIC_STUB_ATTRIBUTE {
   return __QAIC_REMOTE(remote_handle64_close)(h);
}
static __inline int _stub_method(remote_handle64 _handle, uint32_t _mid) {
   remote_arg* _pra = 0;
   int _nErr = 0;
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 0, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_config)(remote_handle64 _handle) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 2;
   return _stub_method(_handle, _mid);
}
static __inline int _stub_method_1(remote_handle64 _handle, uint32_t _mid, const hexagon_nn_uint_option* _in0[1], int _in0Len[1], const hexagon_nn_string_option* _in1[1], int _in1Len[1]) {
   remote_arg _pra[3];
   uint32_t _primIn[2];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in0[0];
   _praIn[0].buf.nLen = (8 * _in0Len[0]);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn[1].buf.pv = (void*) _in1[0];
   _praIn[1].buf.nLen = (260 * _in1Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 3, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_config_with_options)(remote_handle64 _handle, const hexagon_nn_uint_option* uint_options, int uint_optionsLen, const hexagon_nn_string_option* string_options, int string_optionsLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 3;
   return _stub_method_1(_handle, _mid, (const hexagon_nn_uint_option**)&uint_options, (int*)&uint_optionsLen, (const hexagon_nn_string_option**)&string_options, (int*)&string_optionsLen);
}
static __inline int _stub_method_2(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], const hexagon_nn_uint_option* _in1[1], int _in1Len[1], const hexagon_nn_string_option* _in2[1], int _in2Len[1]) {
   remote_arg _pra[3];
   uint32_t _primIn[3];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in1[0];
   _praIn[0].buf.nLen = (8 * _in1Len[0]);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   _praIn[1].buf.pv = (void*) _in2[0];
   _praIn[1].buf.nLen = (260 * _in2Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 3, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_graph_config)(remote_handle64 _handle, hexagon_nn_nn_id id, const hexagon_nn_uint_option* uint_options, int uint_optionsLen, const hexagon_nn_string_option* string_options, int string_optionsLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 4;
   return _stub_method_2(_handle, _mid, (hexagon_nn_nn_id*)&id, (const hexagon_nn_uint_option**)&uint_options, (int*)&uint_optionsLen, (const hexagon_nn_string_option**)&string_options, (int*)&string_optionsLen);
}
static __inline int _stub_method_3(remote_handle64 _handle, uint32_t _mid, unsigned int _rout0[1], unsigned int _rout1[1]) {
   int _numIn[1];
   remote_arg _pra[1];
   uint32_t _primROut[2];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[(_numIn[0] + 0)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 0)].buf.nLen = sizeof(_primROut);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 0, 1, 0, 0), _pra));
   _COPY(_rout0, 0, _primROut, 0, 4);
   _COPY(_rout1, 0, _primROut, 4, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_get_dsp_offset)(remote_handle64 _handle, unsigned int* libhexagon_addr, unsigned int* fastrpc_shell_addr) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 5;
   return _stub_method_3(_handle, _mid, (unsigned int*)libhexagon_addr, (unsigned int*)fastrpc_shell_addr);
}
static __inline int _stub_method_4(remote_handle64 _handle, uint32_t _mid, const char* _in0[1], uint32_t _rout1[1], hexagon_nn_udo_err _rout2[1]) {
   int _in0Len[1];
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[1];
   uint32_t _primROut[2];
   remote_arg* _praIn;
   int _nErr = 0;
   _numIn[0] = 1;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _in0Len[0] = (1 + strlen(_in0[0]));
   _COPY(_primIn, 0, _in0Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in0[0];
   _praIn[0].buf.nLen = (1 * _in0Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _COPY(_rout2, 0, _primROut, 4, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_register_udo_lib)(remote_handle64 _handle, const char* so_path_name, uint32_t* udo_lib_registration_id, hexagon_nn_udo_err* err) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 6;
   return _stub_method_4(_handle, _mid, (const char**)&so_path_name, (uint32_t*)udo_lib_registration_id, (hexagon_nn_udo_err*)err);
}
static __inline int _stub_method_5(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_udo_err _rout1[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[1];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_free_udo_individual_lib)(remote_handle64 _handle, uint32_t udo_lib_registration_id, hexagon_nn_udo_err* err) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 7;
   return _stub_method_5(_handle, _mid, (uint32_t*)&udo_lib_registration_id, (hexagon_nn_udo_err*)err);
}
static __inline int _stub_method_6(remote_handle64 _handle, uint32_t _mid, hexagon_nn_udo_err _rout0[1]) {
   int _numIn[1];
   remote_arg _pra[1];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[(_numIn[0] + 0)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 0)].buf.nLen = sizeof(_primROut);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 0, 1, 0, 0), _pra));
   _COPY(_rout0, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_free_udo_libs)(remote_handle64 _handle, hexagon_nn_udo_err* err) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 8;
   return _stub_method_6(_handle, _mid, (hexagon_nn_udo_err*)err);
}
static __inline int _stub_method_7(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _rout0[1]) {
   int _numIn[1];
   remote_arg _pra[1];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[(_numIn[0] + 0)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 0)].buf.nLen = sizeof(_primROut);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 0, 1, 0, 0), _pra));
   _COPY(_rout0, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_init)(remote_handle64 _handle, hexagon_nn_nn_id* g) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 9;
   return _stub_method_7(_handle, _mid, (hexagon_nn_nn_id*)g);
}
static __inline int _stub_method_8(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], int _in1[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[2];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_set_debug_level)(remote_handle64 _handle, hexagon_nn_nn_id id, int level) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 10;
   return _stub_method_8(_handle, _mid, (hexagon_nn_nn_id*)&id, (int*)&level);
}
static __inline int _stub_method_9(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], const unsigned char* _in1[1], int _in1Len[1], unsigned char* _rout1[1], int _rout1Len[1]) {
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[3];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 1;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in1[0];
   _praIn[0].buf.nLen = (1 * _in1Len[0]);
   _COPY(_primIn, 8, _rout1Len, 0, 4);
   _praROut = (_praIn + _numIn[0] + 0);
   _praROut[0].buf.pv = _rout1[0];
   _praROut[0].buf.nLen = (1 * _rout1Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 1, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_snpprint)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned char* buf, int bufLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 11;
   return _stub_method_9(_handle, _mid, (hexagon_nn_nn_id*)&id, (const unsigned char**)&buf, (int*)&bufLen, (unsigned char**)&buf, (int*)&bufLen);
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_getlog)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned char* buf, int bufLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 12;
   return _stub_method_9(_handle, _mid, (hexagon_nn_nn_id*)&id, (const unsigned char**)&buf, (int*)&bufLen, (unsigned char**)&buf, (int*)&bufLen);
}
static __inline int _stub_method_10(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], unsigned int _in2[1], hexagon_nn_padding_type _in3[1], const hexagon_nn_input* _in4[1], int _in4Len[1], const hexagon_nn_output* _in5[1], int _in5Len[1]) {
   remote_arg _pra[3];
   uint32_t _primIn[6];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in4[0];
   _praIn[0].buf.nLen = (8 * _in4Len[0]);
   _COPY(_primIn, 20, _in5Len, 0, 4);
   _praIn[1].buf.pv = (void*) _in5[0];
   _praIn[1].buf.nLen = (48 * _in5Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 3, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_append_node)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, unsigned int operation, hexagon_nn_padding_type padding, const hexagon_nn_input* inputs, int inputsLen, const hexagon_nn_output* outputs, int outputsLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 13;
   return _stub_method_10(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (unsigned int*)&operation, (hexagon_nn_padding_type*)&padding, (const hexagon_nn_input**)&inputs, (int*)&inputsLen, (const hexagon_nn_output**)&outputs, (int*)&outputsLen);
}
static __inline int _stub_method_11(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], const char* _in2[1], const char* _in3[1], const char* _in4[1], int _in4Len[1], const hexagon_nn_input* _in5[1], int _in5Len[1], const hexagon_nn_output* _in6[1], int _in6Len[1], hexagon_nn_udo_err _rout7[1]) {
   int _in2Len[1];
   int _in3Len[1];
   int _numIn[1];
   remote_arg _pra[7];
   uint32_t _primIn[7];
   uint32_t _primROut[1];
   remote_arg* _praIn;
   int _nErr = 0;
   _numIn[0] = 5;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _in2Len[0] = (1 + strlen(_in2[0]));
   _COPY(_primIn, 8, _in2Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in2[0];
   _praIn[0].buf.nLen = (1 * _in2Len[0]);
   _in3Len[0] = (1 + strlen(_in3[0]));
   _COPY(_primIn, 12, _in3Len, 0, 4);
   _praIn[1].buf.pv = (void*) _in3[0];
   _praIn[1].buf.nLen = (1 * _in3Len[0]);
   _COPY(_primIn, 16, _in4Len, 0, 4);
   _praIn[2].buf.pv = (void*) _in4[0];
   _praIn[2].buf.nLen = (1 * _in4Len[0]);
   _COPY(_primIn, 20, _in5Len, 0, 4);
   _praIn[3].buf.pv = (void*) _in5[0];
   _praIn[3].buf.nLen = (8 * _in5Len[0]);
   _COPY(_primIn, 24, _in6Len, 0, 4);
   _praIn[4].buf.pv = (void*) _in6[0];
   _praIn[4].buf.nLen = (48 * _in6Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 6, 1, 0, 0), _pra));
   _COPY(_rout7, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_append_udo_node)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, const char* package_name, const char* op_type, const char* flattened_static_params, int flattened_static_paramsLen, const hexagon_nn_input* inputs, int inputsLen, const hexagon_nn_output* outputs, int outputsLen, hexagon_nn_udo_err* err) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 14;
   return _stub_method_11(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (const char**)&package_name, (const char**)&op_type, (const char**)&flattened_static_params, (int*)&flattened_static_paramsLen, (const hexagon_nn_input**)&inputs, (int*)&inputsLen, (const hexagon_nn_output**)&outputs, (int*)&outputsLen, (hexagon_nn_udo_err*)err);
}
static __inline int _stub_method_12(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], unsigned int _in4[1], unsigned int _in5[1], const unsigned char* _in6[1], int _in6Len[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[7];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4, 0, 4);
   _COPY(_primIn, 20, _in5, 0, 4);
   _COPY(_primIn, 24, _in6Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in6[0];
   _praIn[0].buf.nLen = (1 * _in6Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_append_const_node)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, unsigned int batches, unsigned int height, unsigned int width, unsigned int depth, const unsigned char* data, int dataLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 15;
   return _stub_method_12(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (unsigned int*)&batches, (unsigned int*)&height, (unsigned int*)&width, (unsigned int*)&depth, (const unsigned char**)&data, (int*)&dataLen);
}
static __inline int _stub_method_13(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], unsigned int _in4[1], unsigned int _in5[1], unsigned int _in6[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[7];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4, 0, 4);
   _COPY(_primIn, 20, _in5, 0, 4);
   _COPY(_primIn, 24, _in6, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_append_empty_const_node)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, unsigned int batches, unsigned int height, unsigned int width, unsigned int depth, unsigned int size) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 16;
   return _stub_method_13(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (unsigned int*)&batches, (unsigned int*)&height, (unsigned int*)&width, (unsigned int*)&depth, (unsigned int*)&size);
}
static __inline int _stub_method_14(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], const unsigned char* _in2[1], int _in2Len[1], unsigned int _in3[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[4];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in2[0];
   _praIn[0].buf.nLen = (1 * _in2Len[0]);
   _COPY(_primIn, 12, _in3, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_populate_const_node)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, const unsigned char* data, int dataLen, unsigned int target_offset) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 17;
   return _stub_method_14(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (const unsigned char**)&data, (int*)&dataLen, (unsigned int*)&target_offset);
}
static __inline int _stub_method_15(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[1];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_prepare)(remote_handle64 _handle, hexagon_nn_nn_id id) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 18;
   return _stub_method_15(_handle, _mid, (hexagon_nn_nn_id*)&id);
}
static __inline int _stub_method_16(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], unsigned int _in4[1], const unsigned char* _in5[1], int _in5Len[1], unsigned int _rout6[1], unsigned int _rout7[1], unsigned int _rout8[1], unsigned int _rout9[1], unsigned char* _rout10[1], int _rout10Len[1], unsigned int _rout11[1]) {
   int _numIn[1];
   remote_arg _pra[4];
   uint32_t _primIn[7];
   uint32_t _primROut[5];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 1;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4, 0, 4);
   _COPY(_primIn, 20, _in5Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in5[0];
   _praIn[0].buf.nLen = (1 * _in5Len[0]);
   _COPY(_primIn, 24, _rout10Len, 0, 4);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROut[0].buf.pv = _rout10[0];
   _praROut[0].buf.nLen = (1 * _rout10Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 2, 0, 0), _pra));
   _COPY(_rout6, 0, _primROut, 0, 4);
   _COPY(_rout7, 0, _primROut, 4, 4);
   _COPY(_rout8, 0, _primROut, 8, 4);
   _COPY(_rout9, 0, _primROut, 12, 4);
   _COPY(_rout11, 0, _primROut, 16, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_execute)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int batches_in, unsigned int height_in, unsigned int width_in, unsigned int depth_in, const unsigned char* data_in, int data_inLen, unsigned int* batches_out, unsigned int* height_out, unsigned int* width_out, unsigned int* depth_out, unsigned char* data_out, int data_outLen, unsigned int* data_len_out) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 19;
   return _stub_method_16(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&batches_in, (unsigned int*)&height_in, (unsigned int*)&width_in, (unsigned int*)&depth_in, (const unsigned char**)&data_in, (int*)&data_inLen, (unsigned int*)batches_out, (unsigned int*)height_out, (unsigned int*)width_out, (unsigned int*)depth_out, (unsigned char**)&data_out, (int*)&data_outLen, (unsigned int*)data_len_out);
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_teardown)(remote_handle64 _handle, hexagon_nn_nn_id id) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 20;
   return _stub_method_15(_handle, _mid, (hexagon_nn_nn_id*)&id);
}
static __inline int _stub_method_17(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], int _in2[1], unsigned int _rout3[1], unsigned int _rout4[1], unsigned int _rout5[1], unsigned int _rout6[1], unsigned char* _rout7[1], int _rout7Len[1], unsigned int _rout8[1]) {
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[4];
   uint32_t _primROut[5];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _rout7Len, 0, 4);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROut[0].buf.pv = _rout7[0];
   _praROut[0].buf.nLen = (1 * _rout7Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 2, 0, 0), _pra));
   _COPY(_rout3, 0, _primROut, 0, 4);
   _COPY(_rout4, 0, _primROut, 4, 4);
   _COPY(_rout5, 0, _primROut, 8, 4);
   _COPY(_rout6, 0, _primROut, 12, 4);
   _COPY(_rout8, 0, _primROut, 16, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_variable_read)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, int output_index, unsigned int* batches_out, unsigned int* height_out, unsigned int* width_out, unsigned int* depth_out, unsigned char* data_out, int data_outLen, unsigned int* data_len_out) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 21;
   return _stub_method_17(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (int*)&output_index, (unsigned int*)batches_out, (unsigned int*)height_out, (unsigned int*)width_out, (unsigned int*)depth_out, (unsigned char**)&data_out, (int*)&data_outLen, (unsigned int*)data_len_out);
}
static __inline int _stub_method_18(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], int _in2[1], unsigned int _in3[1], unsigned int _in4[1], unsigned int _in5[1], unsigned int _in6[1], const unsigned char* _in7[1], int _in7Len[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[8];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4, 0, 4);
   _COPY(_primIn, 20, _in5, 0, 4);
   _COPY(_primIn, 24, _in6, 0, 4);
   _COPY(_primIn, 28, _in7Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in7[0];
   _praIn[0].buf.nLen = (1 * _in7Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_variable_write)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, int output_index, unsigned int batches, unsigned int height, unsigned int width, unsigned int depth, const unsigned char* data_in, int data_inLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 22;
   return _stub_method_18(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (int*)&output_index, (unsigned int*)&batches, (unsigned int*)&height, (unsigned int*)&width, (unsigned int*)&depth, (const unsigned char**)&data_in, (int*)&data_inLen);
}
static __inline int _stub_method_19(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1], int _in2[1], const unsigned char* _in3[1], int _in3Len[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[4];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in3[0];
   _praIn[0].buf.nLen = (1 * _in3Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_variable_write_flat)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int node_id, int output_index, const unsigned char* data_in, int data_inLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 23;
   return _stub_method_19(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&node_id, (int*)&output_index, (const unsigned char**)&data_in, (int*)&data_inLen);
}
static __inline int _stub_method_20(remote_handle64 _handle, uint32_t _mid, unsigned int _in0[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[1];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_set_powersave_level)(remote_handle64 _handle, unsigned int level) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 24;
   return _stub_method_20(_handle, _mid, (unsigned int*)&level);
}
static __inline int _stub_method_21(remote_handle64 _handle, uint32_t _mid, hexagon_nn_corner_type _in0[1], hexagon_nn_dcvs_type _in1[1], unsigned int _in2[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[3];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_set_powersave_details)(remote_handle64 _handle, hexagon_nn_corner_type corner, hexagon_nn_dcvs_type dcvs, unsigned int latency) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 25;
   return _stub_method_21(_handle, _mid, (hexagon_nn_corner_type*)&corner, (hexagon_nn_dcvs_type*)&dcvs, (unsigned int*)&latency);
}
static __inline int _stub_method_22(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], hexagon_nn_perfinfo* _rout1[1], int _rout1Len[1], unsigned int _rout2[1]) {
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[2];
   uint32_t _primROut[1];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _rout1Len, 0, 4);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROut[0].buf.pv = _rout1[0];
   _praROut[0].buf.nLen = (16 * _rout1Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 2, 0, 0), _pra));
   _COPY(_rout2, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_get_perfinfo)(remote_handle64 _handle, hexagon_nn_nn_id id, hexagon_nn_perfinfo* info_out, int info_outLen, unsigned int* n_items) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 26;
   return _stub_method_22(_handle, _mid, (hexagon_nn_nn_id*)&id, (hexagon_nn_perfinfo**)&info_out, (int*)&info_outLen, (unsigned int*)n_items);
}
static __inline int _stub_method_23(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _in1[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[2];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_reset_perfinfo)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int event) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 27;
   return _stub_method_23(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)&event);
}
static __inline int _stub_method_24(remote_handle64 _handle, uint32_t _mid, hexagon_nn_nn_id _in0[1], unsigned int _rout1[1], unsigned int _rout2[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[1];
   uint32_t _primROut[2];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _COPY(_rout2, 0, _primROut, 4, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_last_execution_cycles)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int* cycles_lo, unsigned int* cycles_hi) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 28;
   return _stub_method_24(_handle, _mid, (hexagon_nn_nn_id*)&id, (unsigned int*)cycles_lo, (unsigned int*)cycles_hi);
}
static __inline int _stub_method_25(remote_handle64 _handle, uint32_t _mid, int _rout0[1]) {
   int _numIn[1];
   remote_arg _pra[1];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[(_numIn[0] + 0)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 0)].buf.nLen = sizeof(_primROut);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 0, 1, 0, 0), _pra));
   _COPY(_rout0, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_version)(remote_handle64 _handle, int* ver) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 29;
   return _stub_method_25(_handle, _mid, (int*)ver);
}
static __inline int _stub_method_26(remote_handle64 _handle, uint32_t _mid, const char* _in0[1], unsigned int _rout1[1]) {
   int _in0Len[1];
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[1];
   uint32_t _primROut[1];
   remote_arg* _praIn;
   int _nErr = 0;
   _numIn[0] = 1;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _in0Len[0] = (1 + strlen(_in0[0]));
   _COPY(_primIn, 0, _in0Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in0[0];
   _praIn[0].buf.nLen = (1 * _in0Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_op_name_to_id)(remote_handle64 _handle, const char* name, unsigned int* node_id) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 30;
   return _stub_method_26(_handle, _mid, (const char**)&name, (unsigned int*)node_id);
}
static __inline int _stub_method_27(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], unsigned int _in1[1], char* _rout2[1], int _rout2Len[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[3];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _rout2Len, 0, 4);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 0);
   _praROut[0].buf.pv = _rout2[0];
   _praROut[0].buf.nLen = (1 * _rout2Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   if(_rout2Len[0] > 0)
   {
      _rout2[0][(_rout2Len[0] - 1)] = 0;
   }
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_op_id_to_name)(remote_handle64 _handle, unsigned int node_id, char* name, int nameLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 31;
   return _stub_method_27(_handle, 31, &_mid, (unsigned int*)&node_id, (char**)&name, (int*)&nameLen);
}
static __inline int _stub_method_28(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], unsigned int _rout2[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[2];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout2, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_get_num_nodes_in_graph)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int* num_nodes) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 32;
   return _stub_method_28(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (unsigned int*)num_nodes);
}
static __inline int _stub_method_29(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[1];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_disable_dcvs)(remote_handle64 _handle) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 33;
   return _stub_method_29(_handle, 31, &_mid);
}
static __inline int _stub_method_30(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], int _rout1[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[1];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_GetHexagonBinaryVersion)(remote_handle64 _handle, int* ver) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 34;
   return _stub_method_30(_handle, 31, &_mid, (int*)ver);
}
static __inline int _stub_method_31(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], const unsigned char* _in1[1], int _in1Len[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[2];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in1[0];
   _praIn[0].buf.nLen = (1 * _in1Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_PrintLog)(remote_handle64 _handle, const unsigned char* buf, int bufLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 35;
   return _stub_method_31(_handle, 31, &_mid, (const unsigned char**)&buf, (int*)&bufLen);
}
static __inline int _stub_unpack(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, unsigned int _rout0[1], unsigned int _rout1[1], unsigned int _rout2[1], unsigned int _rout3[1], unsigned char* _rout4[1], int _rout4Len[1], unsigned int _rout5[1], unsigned int _rout6[1]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _COPY(_rout0, 0, _primROut, 0, 4);
   _COPY(_rout1, 0, _primROut, 4, 4);
   _COPY(_rout2, 0, _primROut, 8, 4);
   _COPY(_rout3, 0, _primROut, 12, 4);
   _COPY(_rout5, 0, _primROut, 16, 4);
   _COPY(_rout6, 0, _primROut, 20, 4);
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +1;
   return _nErr;
}
static __inline int _stub_unpack_1(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, hexagon_nn_tensordef _rout0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   _allocator _al[1] = {{0}};
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _allocator_init(_al, 0, 0);
   _TRY(_nErr, _stub_unpack((_praROutPost + 0), _ppraROutPost, ((char*)_primROut + 0), (unsigned int*)&(((uint32_t*)_rout0)[0]), (unsigned int*)&(((uint32_t*)_rout0)[1]), (unsigned int*)&(((uint32_t*)_rout0)[2]), (unsigned int*)&(((uint32_t*)_rout0)[3]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout0)[4]), (unsigned char**)&(((uint64_t*)_rout0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout0)[5]), (int*)&(((uint32_t*)_rout0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[6]), (unsigned int*)&(((uint32_t*)_rout0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[7]), (unsigned int*)&(((uint32_t*)_rout0)[8]))));
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +0;
   _CATCH(_nErr) {}
   _allocator_deinit(_al);
   return _nErr;
}
static __inline int _stub_unpack_2(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, const hexagon_nn_tensordef _in0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +0;
   return _nErr;
}
static __inline int _stub_pack(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, unsigned int _rout0[1], unsigned int _rout1[1], unsigned int _rout2[1], unsigned int _rout3[1], unsigned char* _rout4[1], int _rout4Len[1], unsigned int _rout5[1], unsigned int _rout6[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _rout4Len, 0, 4);
   _praROut[0].buf.pv = _rout4[0];
   _praROut[0].buf.nLen = (1 * _rout4Len[0]);
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +1;
   return _nErr;
}
static __inline int _stub_pack_1(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, hexagon_nn_tensordef _rout0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _TRY(_nErr, _stub_pack(_al, (_praIn + 0), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 0), ((char*)_primROut + 0), (unsigned int*)&(((uint32_t*)_rout0)[0]), (unsigned int*)&(((uint32_t*)_rout0)[1]), (unsigned int*)&(((uint32_t*)_rout0)[2]), (unsigned int*)&(((uint32_t*)_rout0)[3]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout0)[4]), (unsigned char**)&(((uint64_t*)_rout0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout0)[5]), (int*)&(((uint32_t*)_rout0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[6]), (unsigned int*)&(((uint32_t*)_rout0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[7]), (unsigned int*)&(((uint32_t*)_rout0)[8]))));
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   _CATCH(_nErr) {}
   return _nErr;
}
static __inline int _stub_pack_2(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, unsigned int _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], const unsigned char* _in4[1], int _in4Len[1], unsigned int _in5[1], unsigned int _in6[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4Len, 0, 4);
   _praIn[0].buf.pv = (void*) _in4[0];
   _praIn[0].buf.nLen = (1 * _in4Len[0]);
   _COPY(_primIn, 20, _in5, 0, 4);
   _COPY(_primIn, 24, _in6, 0, 4);
   _ppraInStart[0] += (_praIn - _praInStart) + 1;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   return _nErr;
}
static __inline int _stub_pack_3(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, const hexagon_nn_tensordef _in0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _TRY(_nErr, _stub_pack_2(_al, (_praIn + 0), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 0), 0, (unsigned int*)&(((uint32_t*)_in0)[0]), (unsigned int*)&(((uint32_t*)_in0)[1]), (unsigned int*)&(((uint32_t*)_in0)[2]), (unsigned int*)&(((uint32_t*)_in0)[3]), SLIM_IFPTR32((const unsigned char**)&(((uint32_t*)_in0)[4]), (const unsigned char**)&(((uint64_t*)_in0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_in0)[5]), (int*)&(((uint32_t*)_in0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[6]), (unsigned int*)&(((uint32_t*)_in0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[7]), (unsigned int*)&(((uint32_t*)_in0)[8]))));
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   _CATCH(_nErr) {}
   return _nErr;
}
static __inline void _count(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], unsigned int _rout0[1], unsigned int _rout1[1], unsigned int _rout2[1], unsigned int _rout3[1], unsigned char* _rout4[1], int _rout4Len[1], unsigned int _rout5[1], unsigned int _rout6[1]) {
   _numIn[0] += 0;
   _numROut[0] += 1;
   _numInH[0] += 0;
   _numROutH[0] += 0;
}
static __inline void _count_1(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], hexagon_nn_tensordef _rout0[SLIM_IFPTR32(8, 5)]) {
   _numIn[0] += 0;
   _numROut[0] += 0;
   _numInH[0] += 0;
   _numROutH[0] += 0;
   _count(_numIn, _numROut, _numInH, _numROutH, (unsigned int*)&(((uint32_t*)_rout0)[0]), (unsigned int*)&(((uint32_t*)_rout0)[1]), (unsigned int*)&(((uint32_t*)_rout0)[2]), (unsigned int*)&(((uint32_t*)_rout0)[3]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout0)[4]), (unsigned char**)&(((uint64_t*)_rout0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout0)[5]), (int*)&(((uint32_t*)_rout0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[6]), (unsigned int*)&(((uint32_t*)_rout0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[7]), (unsigned int*)&(((uint32_t*)_rout0)[8])));
}
static __inline void _count_2(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], unsigned int _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], const unsigned char* _in4[1], int _in4Len[1], unsigned int _in5[1], unsigned int _in6[1]) {
   _numIn[0] += 1;
   _numROut[0] += 0;
   _numInH[0] += 0;
   _numROutH[0] += 0;
}
static __inline void _count_3(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], const hexagon_nn_tensordef _in0[SLIM_IFPTR32(8, 5)]) {
   _numIn[0] += 0;
   _numROut[0] += 0;
   _numInH[0] += 0;
   _numROutH[0] += 0;
   _count_2(_numIn, _numROut, _numInH, _numROutH, (unsigned int*)&(((uint32_t*)_in0)[0]), (unsigned int*)&(((uint32_t*)_in0)[1]), (unsigned int*)&(((uint32_t*)_in0)[2]), (unsigned int*)&(((uint32_t*)_in0)[3]), SLIM_IFPTR32((const unsigned char**)&(((uint32_t*)_in0)[4]), (const unsigned char**)&(((uint64_t*)_in0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_in0)[5]), (int*)&(((uint32_t*)_in0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[6]), (unsigned int*)&(((uint32_t*)_in0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[7]), (unsigned int*)&(((uint32_t*)_in0)[8])));
}
static __inline int _stub_method_32(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], const hexagon_nn_tensordef* _in2[1], int _in2Len[1], hexagon_nn_tensordef* _rout3[1], int _rout3Len[1]) {
   remote_arg* _pra;
   int _numIn[1];
   int _numROut[1];
   int _numInH[1];
   int _numROutH[1];
   char* _seq_nat2;
   int _ii;
   char* _seq_nat3;
   _allocator _al[1] = {{0}};
   uint32_t _primIn[4];
   remote_arg* _praIn;
   remote_arg* _praROut;
   remote_arg* _praROutPost;
   remote_arg** _ppraROutPost = &_praROutPost;
   remote_arg** _ppraIn = &_praIn;
   remote_arg** _ppraROut = &_praROut;
   remote_arg* _praHIn = 0;
   remote_arg** _ppraHIn = &_praHIn;
   remote_arg* _praHROut = 0;
   remote_arg** _ppraHROut = &_praHROut;
   char* _seq_primIn2;
   int _nErr = 0;
   char* _seq_primIn3;
   char* _seq_primROut3;
   _numIn[0] = 2;
   _numROut[0] = 1;
   _numInH[0] = 0;
   _numROutH[0] = 0;
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _count_3(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0])));
   }
   for(_ii = 0, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _count_1(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0])));
   }
   _allocator_init(_al, 0, 0);
   _ALLOCATE(_nErr, _al, ((((((((_numIn[0] + _numROut[0]) + _numInH[0]) + _numROutH[0]) + 1) + 0) + 0) + 0) * sizeof(_pra[0])), 4, _pra);
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 0);
   _praROutPost = _praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   if(_praHIn == 0)
   {
      _praHIn = ((_praROut + _numROut[0]) + 0);
   }
   if(_praHROut == 0)
      (_praHROut = _praHIn + _numInH[0] + 0);
   _ALLOCATE(_nErr, _al, (_in2Len[0] * 28), 4, _praIn[0].buf.pv);
   _praIn[0].buf.nLen = (28 * _in2Len[0]);
   for(_ii = 0, _seq_primIn2 = (char*)_praIn[0].buf.pv, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_primIn2 = (_seq_primIn2 + 28), _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_3(_al, (_praIn + 1), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn2, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   _COPY(_primIn, 12, _rout3Len, 0, 4);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 4), 4, _praIn[1].buf.pv);
   _praIn[1].buf.nLen = (4 * _rout3Len[0]);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 24), 4, _praROut[0].buf.pv);
   _praROut[0].buf.nLen = (24 * _rout3Len[0]);
   for(_ii = 0, _seq_primIn3 = (char*)_praIn[1].buf.pv, _seq_primROut3 = (char*)_praROut[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primIn3 = (_seq_primIn3 + 4), _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_1(_al, (_praIn + 2), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn3, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _ASSERT(_nErr, (_numInH[0] + 0) <= 15);
   _ASSERT(_nErr, (_numROutH[0] + 0) <= 15);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, (_numIn[0] + 1), (_numROut[0] + 0), (_numInH[0] + 0), (_numROutH[0] + 0)), _pra));
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_2((_praROutPost + 0), _ppraROutPost, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   for(_ii = 0, _seq_primROut3 = (char*)_praROutPost[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_1((_praROutPost + 1), _ppraROutPost, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _CATCH(_nErr) {}
   _allocator_deinit(_al);
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_execute_new)(remote_handle64 _handle, hexagon_nn_nn_id id, const hexagon_nn_tensordef* inputs, int inputsLen, hexagon_nn_tensordef* outputs, int outputsLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 36;
   return _stub_method_32(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (const hexagon_nn_tensordef**)&inputs, (int*)&inputsLen, (hexagon_nn_tensordef**)&outputs, (int*)&outputsLen);
}
static __inline int _stub_unpack_3(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, hexagon_nn_execute_result _rout0[1], unsigned char* _rout1[1], int _rout1Len[1], unsigned int _rout2[1]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _COPY(_rout0, 0, _primROut, 0, 4);
   _COPY(_rout2, 0, _primROut, 4, 4);
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +1;
   return _nErr;
}
static __inline int _stub_unpack_4(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, unsigned int _rout0[1], unsigned int _rout1[1], unsigned int _rout2[1], unsigned int _rout3[1], unsigned char* _rout4[1], int _rout4Len[1], unsigned int _rout5[1], unsigned int _rout6[1]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _COPY(_rout0, 0, _primROut, 0, 4);
   _COPY(_rout1, 0, _primROut, 4, 4);
   _COPY(_rout2, 0, _primROut, 8, 4);
   _COPY(_rout3, 0, _primROut, 12, 4);
   _COPY(_rout5, 0, _primROut, 16, 4);
   _COPY(_rout6, 0, _primROut, 20, 4);
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +1;
   return _nErr;
}
static __inline int _stub_unpack_5(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, hexagon_nn_tensordef _rout0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   _allocator _al[1] = {{0}};
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _allocator_init(_al, 0, 0);
   _TRY(_nErr, _stub_unpack_4((_praROutPost + 0), _ppraROutPost, ((char*)_primROut + 0), (unsigned int*)&(((uint32_t*)_rout0)[0]), (unsigned int*)&(((uint32_t*)_rout0)[1]), (unsigned int*)&(((uint32_t*)_rout0)[2]), (unsigned int*)&(((uint32_t*)_rout0)[3]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout0)[4]), (unsigned char**)&(((uint64_t*)_rout0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout0)[5]), (int*)&(((uint32_t*)_rout0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[6]), (unsigned int*)&(((uint32_t*)_rout0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[7]), (unsigned int*)&(((uint32_t*)_rout0)[8]))));
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +0;
   _CATCH(_nErr) {}
   _allocator_deinit(_al);
   return _nErr;
}
static __inline int _stub_unpack_6(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, const hexagon_nn_tensordef _in0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +0;
   return _nErr;
}
static __inline int _stub_pack_4(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, hexagon_nn_execute_result _rout0[1], unsigned char* _rout1[1], int _rout1Len[1], unsigned int _rout2[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _rout1Len, 0, 4);
   _praROut[0].buf.pv = _rout1[0];
   _praROut[0].buf.nLen = (1 * _rout1Len[0]);
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +1;
   return _nErr;
}
static __inline int _stub_pack_5(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, unsigned int _rout0[1], unsigned int _rout1[1], unsigned int _rout2[1], unsigned int _rout3[1], unsigned char* _rout4[1], int _rout4Len[1], unsigned int _rout5[1], unsigned int _rout6[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _rout4Len, 0, 4);
   _praROut[0].buf.pv = _rout4[0];
   _praROut[0].buf.nLen = (1 * _rout4Len[0]);
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +1;
   return _nErr;
}
static __inline int _stub_pack_6(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, hexagon_nn_tensordef _rout0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _TRY(_nErr, _stub_pack_5(_al, (_praIn + 0), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 0), ((char*)_primROut + 0), (unsigned int*)&(((uint32_t*)_rout0)[0]), (unsigned int*)&(((uint32_t*)_rout0)[1]), (unsigned int*)&(((uint32_t*)_rout0)[2]), (unsigned int*)&(((uint32_t*)_rout0)[3]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout0)[4]), (unsigned char**)&(((uint64_t*)_rout0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout0)[5]), (int*)&(((uint32_t*)_rout0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[6]), (unsigned int*)&(((uint32_t*)_rout0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout0)[7]), (unsigned int*)&(((uint32_t*)_rout0)[8]))));
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   _CATCH(_nErr) {}
   return _nErr;
}
static __inline int _stub_pack_7(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, unsigned int _in0[1], unsigned int _in1[1], unsigned int _in2[1], unsigned int _in3[1], const unsigned char* _in4[1], int _in4Len[1], unsigned int _in5[1], unsigned int _in6[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _COPY(_primIn, 12, _in3, 0, 4);
   _COPY(_primIn, 16, _in4Len, 0, 4);
   _praIn[0].buf.pv = (void*) _in4[0];
   _praIn[0].buf.nLen = (1 * _in4Len[0]);
   _COPY(_primIn, 20, _in5, 0, 4);
   _COPY(_primIn, 24, _in6, 0, 4);
   _ppraInStart[0] += (_praIn - _praInStart) + 1;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   return _nErr;
}
static __inline int _stub_pack_8(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, const hexagon_nn_tensordef _in0[SLIM_IFPTR32(8, 5)]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _TRY(_nErr, _stub_pack_7(_al, (_praIn + 0), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 0), 0, (unsigned int*)&(((uint32_t*)_in0)[0]), (unsigned int*)&(((uint32_t*)_in0)[1]), (unsigned int*)&(((uint32_t*)_in0)[2]), (unsigned int*)&(((uint32_t*)_in0)[3]), SLIM_IFPTR32((const unsigned char**)&(((uint32_t*)_in0)[4]), (const unsigned char**)&(((uint64_t*)_in0)[2])), SLIM_IFPTR32((int*)&(((uint32_t*)_in0)[5]), (int*)&(((uint32_t*)_in0)[6])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[6]), (unsigned int*)&(((uint32_t*)_in0)[7])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_in0)[7]), (unsigned int*)&(((uint32_t*)_in0)[8]))));
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   _CATCH(_nErr) {}
   return _nErr;
}
static __inline void _count_4(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], hexagon_nn_execute_result _rout0[1], unsigned char* _rout1[1], int _rout1Len[1], unsigned int _rout2[1]) {
   _numIn[0] += 0;
   _numROut[0] += 1;
   _numInH[0] += 0;
   _numROutH[0] += 0;
}
static __inline int _stub_method_33(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], const hexagon_nn_tensordef* _in2[1], int _in2Len[1], hexagon_nn_tensordef* _rout3[1], int _rout3Len[1], hexagon_nn_execute_info _rout4[SLIM_IFPTR32(4, 3)]) {
   remote_arg* _pra;
   int _numIn[1];
   int _numROut[1];
   int _numInH[1];
   int _numROutH[1];
   char* _seq_nat2;
   int _ii;
   char* _seq_nat3;
   _allocator _al[1] = {{0}};
   uint32_t _primIn[5];
   uint32_t _primROut[2];
   remote_arg* _praIn;
   remote_arg* _praROut;
   remote_arg* _praROutPost;
   remote_arg** _ppraROutPost = &_praROutPost;
   remote_arg** _ppraIn = &_praIn;
   remote_arg** _ppraROut = &_praROut;
   remote_arg* _praHIn = 0;
   remote_arg** _ppraHIn = &_praHIn;
   remote_arg* _praHROut = 0;
   remote_arg** _ppraHROut = &_praHROut;
   char* _seq_primIn2;
   int _nErr = 0;
   char* _seq_primIn3;
   char* _seq_primROut3;
   _numIn[0] = 2;
   _numROut[0] = 1;
   _numInH[0] = 0;
   _numROutH[0] = 0;
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _count_3(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0])));
   }
   for(_ii = 0, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _count_1(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0])));
   }
   _count_4(_numIn, _numROut, _numInH, _numROutH, (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5])));
   _allocator_init(_al, 0, 0);
   _ALLOCATE(_nErr, _al, ((((((((_numIn[0] + _numROut[0]) + _numInH[0]) + _numROutH[0]) + 1) + 1) + 0) + 0) * sizeof(_pra[0])), 4, _pra);
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROutPost = _praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   if(_praHIn == 0)
   {
      _praHIn = ((_praROut + _numROut[0]) + 1);
   }
   if(_praHROut == 0)
      (_praHROut = _praHIn + _numInH[0] + 0);
   _ALLOCATE(_nErr, _al, (_in2Len[0] * 28), 4, _praIn[0].buf.pv);
   _praIn[0].buf.nLen = (28 * _in2Len[0]);
   for(_ii = 0, _seq_primIn2 = (char*)_praIn[0].buf.pv, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_primIn2 = (_seq_primIn2 + 28), _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_8(_al, (_praIn + 1), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn2, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   _COPY(_primIn, 12, _rout3Len, 0, 4);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 4), 4, _praIn[1].buf.pv);
   _praIn[1].buf.nLen = (4 * _rout3Len[0]);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 24), 4, _praROut[0].buf.pv);
   _praROut[0].buf.nLen = (24 * _rout3Len[0]);
   for(_ii = 0, _seq_primIn3 = (char*)_praIn[1].buf.pv, _seq_primROut3 = (char*)_praROut[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primIn3 = (_seq_primIn3 + 4), _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_6(_al, (_praIn + 2), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn3, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _TRY(_nErr, _stub_pack_4(_al, (_praIn + 2), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 16), ((char*)_primROut + 0), (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5]))));
   _ASSERT(_nErr, (_numInH[0] + 0) <= 15);
   _ASSERT(_nErr, (_numROutH[0] + 0) <= 15);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, (_numIn[0] + 1), (_numROut[0] + 1), (_numInH[0] + 0), (_numROutH[0] + 0)), _pra));
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_6((_praROutPost + 0), _ppraROutPost, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   for(_ii = 0, _seq_primROut3 = (char*)_praROutPost[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_5((_praROutPost + 1), _ppraROutPost, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _TRY(_nErr, _stub_unpack_3((_praROutPost + 1), _ppraROutPost, ((char*)_primROut + 0), (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5]))));
   _CATCH(_nErr) {}
   _allocator_deinit(_al);
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_execute_with_info)(remote_handle64 _handle, hexagon_nn_nn_id id, const hexagon_nn_tensordef* inputs, int inputsLen, hexagon_nn_tensordef* outputs, int outputsLen, hexagon_nn_execute_info* execute_info) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 37;
   return _stub_method_33(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (const hexagon_nn_tensordef**)&inputs, (int*)&inputsLen, (hexagon_nn_tensordef**)&outputs, (int*)&outputsLen, (hexagon_nn_execute_info*)execute_info);
}
static __inline int _stub_method_34(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _rout1[1], const hexagon_nn_initinfo _in2[2]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[3];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in2, 0, 8);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout1, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_init_with_info)(remote_handle64 _handle, hexagon_nn_nn_id* g, const hexagon_nn_initinfo* info) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 38;
   return _stub_method_34(_handle, 31, &_mid, (hexagon_nn_nn_id*)g, (const hexagon_nn_initinfo*)info);
}
static __inline int _stub_method_35(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], hexagon_nn_nn_id _in2[1], unsigned int _rout3[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[3];
   uint32_t _primROut[1];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout3, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_get_nodetype)(remote_handle64 _handle, hexagon_nn_nn_id graph_id, hexagon_nn_nn_id node_id, unsigned int* node_type) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 39;
   return _stub_method_35(_handle, 31, &_mid, (hexagon_nn_nn_id*)&graph_id, (hexagon_nn_nn_id*)&node_id, (unsigned int*)node_type);
}
static __inline int _stub_method_36(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], unsigned int _rout2[1], unsigned int _rout3[1]) {
   int _numIn[1];
   remote_arg _pra[2];
   uint32_t _primIn[2];
   uint32_t _primROut[2];
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 1, 0, 0), _pra));
   _COPY(_rout2, 0, _primROut, 0, 4);
   _COPY(_rout3, 0, _primROut, 4, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_multi_execution_cycles)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int* cycles_lo, unsigned int* cycles_hi) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 40;
   return _stub_method_36(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (unsigned int*)cycles_lo, (unsigned int*)cycles_hi);
}
static __inline int _stub_method_37(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], int _in1[1]) {
   remote_arg _pra[1];
   uint32_t _primIn[2];
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_get_power)(remote_handle64 _handle, int type) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 41;
   return _stub_method_37(_handle, 31, &_mid, (int*)&type);
}
static __inline int _stub_method_38(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], const char* _in2[1], int _in3[1]) {
   int _in2Len[1];
   remote_arg _pra[2];
   uint32_t _primIn[4];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _in2Len[0] = (1 + strlen(_in2[0]));
   _COPY(_primIn, 8, _in2Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in2[0];
   _praIn[0].buf.nLen = (1 * _in2Len[0]);
   _COPY(_primIn, 12, _in3, 0, 4);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_set_graph_option)(remote_handle64 _handle, hexagon_nn_nn_id id, const char* name, int value) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 42;
   return _stub_method_38(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (const char**)&name, (int*)&value);
}
static __inline int _stub_method_39(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], const unsigned char* _in2[1], int _in2Len[1]) {
   remote_arg _pra[2];
   uint32_t _primIn[3];
   remote_arg* _praIn;
   int _nErr = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in2[0];
   _praIn[0].buf.nLen = (1 * _in2Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 0, 0, 0), _pra));
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_populate_graph)(remote_handle64 _handle, hexagon_nn_nn_id id, const unsigned char* graph_data, int graph_dataLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 43;
   return _stub_method_39(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (const unsigned char**)&graph_data, (int*)&graph_dataLen);
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_serialize_size)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned int* serialized_obj_size_out, unsigned int* return_code) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 44;
   return _stub_method_36(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (unsigned int*)serialized_obj_size_out, (unsigned int*)return_code);
}
static __inline int _stub_method_40(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], unsigned char* _rout2[1], int _rout2Len[1], unsigned int _rout3[1]) {
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[3];
   uint32_t _primROut[1];
   remote_arg* _praIn;
   remote_arg* _praROut;
   int _nErr = 0;
   _numIn[0] = 0;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _rout2Len, 0, 4);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROut[0].buf.pv = _rout2[0];
   _praROut[0].buf.nLen = (1 * _rout2Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 1, 2, 0, 0), _pra));
   _COPY(_rout3, 0, _primROut, 0, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_serialize)(remote_handle64 _handle, hexagon_nn_nn_id id, unsigned char* buffer, int bufferLen, unsigned int* return_code) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 45;
   return _stub_method_40(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (unsigned char**)&buffer, (int*)&bufferLen, (unsigned int*)return_code);
}
static __inline int _stub_method_41(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], const unsigned char* _in1[1], int _in1Len[1], hexagon_nn_nn_id _rout2[1], unsigned int _rout3[1]) {
   int _numIn[1];
   remote_arg _pra[3];
   uint32_t _primIn[2];
   uint32_t _primROut[2];
   remote_arg* _praIn;
   int _nErr = 0;
   _numIn[0] = 1;
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn = (_pra + 1);
   _praIn[0].buf.pv = (void*) _in1[0];
   _praIn[0].buf.nLen = (1 * _in1Len[0]);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, 2, 1, 0, 0), _pra));
   _COPY(_rout2, 0, _primROut, 0, 4);
   _COPY(_rout3, 0, _primROut, 4, 4);
   _CATCH(_nErr) {}
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_deserialize)(remote_handle64 _handle, const unsigned char* buffer, int bufferLen, hexagon_nn_nn_id* new_graph_out, unsigned int* return_code) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 46;
   return _stub_method_41(_handle, 31, &_mid, (const unsigned char**)&buffer, (int*)&bufferLen, (hexagon_nn_nn_id*)new_graph_out, (unsigned int*)return_code);
}
static __inline int _stub_unpack_7(remote_arg* _praROutPost, remote_arg* _ppraROutPost[1], void* _primROut, const hexagon_nn_execute_option _in0[3]) {
   int _nErr = 0;
   remote_arg* _praROutPostStart = _praROutPost;
   remote_arg** _ppraROutPostStart = _ppraROutPost;
   _ppraROutPost = &_praROutPost;
   _ppraROutPostStart[0] += (_praROutPost - _praROutPostStart) +0;
   return _nErr;
}
static __inline int _stub_pack_9(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, unsigned int _in0[1], const unsigned char* _in1[1], int _in1Len[1]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1Len, 0, 4);
   _praIn[0].buf.pv = (void*) _in1[0];
   _praIn[0].buf.nLen = (1 * _in1Len[0]);
   _ppraInStart[0] += (_praIn - _praInStart) + 1;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   return _nErr;
}
static __inline int _stub_pack_10(_allocator* _al, remote_arg* _praIn, remote_arg* _ppraIn[1], remote_arg* _praROut, remote_arg* _ppraROut[1], remote_arg* _praHIn, remote_arg* _ppraHIn[1], remote_arg* _praHROut, remote_arg* _ppraHROut[1], void* _primIn, void* _primROut, const hexagon_nn_execute_option _in0[3]) {
   int _nErr = 0;
   remote_arg* _praInStart = _praIn;
   remote_arg** _ppraInStart = _ppraIn;
   remote_arg* _praROutStart = _praROut;
   remote_arg** _ppraROutStart = _ppraROut;
   _ppraIn = &_praIn;
   _ppraROut = &_praROut;
   _TRY(_nErr, _stub_pack_9(_al, (_praIn + 0), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 0), 0, (unsigned int*)&(((uint32_t*)_in0)[0]), SLIM_IFPTR32((const unsigned char**)&(((uint32_t*)_in0)[1]), (const unsigned char**)&(((uint64_t*)_in0)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_in0)[2]), (int*)&(((uint32_t*)_in0)[4]))));
   _ppraInStart[0] += (_praIn - _praInStart) + 0;
   _ppraROutStart[0] += (_praROut - _praROutStart) +0;
   _CATCH(_nErr) {}
   return _nErr;
}
static __inline void _count_5(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], unsigned int _in0[1], const unsigned char* _in1[1], int _in1Len[1]) {
   _numIn[0] += 1;
   _numROut[0] += 0;
   _numInH[0] += 0;
   _numROutH[0] += 0;
}
static __inline void _count_6(int _numIn[1], int _numROut[1], int _numInH[1], int _numROutH[1], const hexagon_nn_execute_option _in0[3]) {
   _numIn[0] += 0;
   _numROut[0] += 0;
   _numInH[0] += 0;
   _numROutH[0] += 0;
   _count_5(_numIn, _numROut, _numInH, _numROutH, (unsigned int*)&(((uint32_t*)_in0)[0]), SLIM_IFPTR32((const unsigned char**)&(((uint32_t*)_in0)[1]), (const unsigned char**)&(((uint64_t*)_in0)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_in0)[2]), (int*)&(((uint32_t*)_in0)[4])));
}
static __inline int _stub_method_42(remote_handle64 _handle, uint32_t _mid, uint32_t _in0[1], hexagon_nn_nn_id _in1[1], const hexagon_nn_tensordef* _in2[1], int _in2Len[1], hexagon_nn_tensordef* _rout3[1], int _rout3Len[1], hexagon_nn_execute_info _rout4[SLIM_IFPTR32(4, 3)], const hexagon_nn_execute_option* _in5[1], int _in5Len[1]) {
   remote_arg* _pra;
   int _numIn[1];
   int _numROut[1];
   int _numInH[1];
   int _numROutH[1];
   char* _seq_nat2;
   int _ii;
   char* _seq_nat3;
   char* _seq_nat5;
   _allocator _al[1] = {{0}};
   uint32_t _primIn[6];
   uint32_t _primROut[2];
   remote_arg* _praIn;
   remote_arg* _praROut;
   remote_arg* _praROutPost;
   remote_arg** _ppraROutPost = &_praROutPost;
   remote_arg** _ppraIn = &_praIn;
   remote_arg** _ppraROut = &_praROut;
   remote_arg* _praHIn = 0;
   remote_arg** _ppraHIn = &_praHIn;
   remote_arg* _praHROut = 0;
   remote_arg** _ppraHROut = &_praHROut;
   char* _seq_primIn2;
   int _nErr = 0;
   char* _seq_primIn3;
   char* _seq_primROut3;
   char* _seq_primIn5;
   _numIn[0] = 3;
   _numROut[0] = 1;
   _numInH[0] = 0;
   _numROutH[0] = 0;
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _count_3(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0])));
   }
   for(_ii = 0, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _count_1(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0])));
   }
   _count_4(_numIn, _numROut, _numInH, _numROutH, (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5])));
   for(_ii = 0, _seq_nat5 = (char*)_in5[0];_ii < (int)_in5Len[0];++_ii, _seq_nat5 = (_seq_nat5 + SLIM_IFPTR32(12, 24)))
   {
      _count_6(_numIn, _numROut, _numInH, _numROutH, SLIM_IFPTR32((const hexagon_nn_execute_option*)&(((uint32_t*)_seq_nat5)[0]), (const hexagon_nn_execute_option*)&(((uint64_t*)_seq_nat5)[0])));
   }
   _allocator_init(_al, 0, 0);
   _ALLOCATE(_nErr, _al, ((((((((_numIn[0] + _numROut[0]) + _numInH[0]) + _numROutH[0]) + 1) + 1) + 0) + 0) * sizeof(_pra[0])), 4, _pra);
   _pra[0].buf.pv = (void*)_primIn;
   _pra[0].buf.nLen = sizeof(_primIn);
   _pra[(_numIn[0] + 1)].buf.pv = (void*)_primROut;
   _pra[(_numIn[0] + 1)].buf.nLen = sizeof(_primROut);
   _praIn = (_pra + 1);
   _praROut = (_praIn + _numIn[0] + 1);
   _praROutPost = _praROut;
   _COPY(_primIn, 0, _in0, 0, 4);
   _COPY(_primIn, 4, _in1, 0, 4);
   _COPY(_primIn, 8, _in2Len, 0, 4);
   if(_praHIn == 0)
   {
      _praHIn = ((_praROut + _numROut[0]) + 1);
   }
   if(_praHROut == 0)
      (_praHROut = _praHIn + _numInH[0] + 0);
   _ALLOCATE(_nErr, _al, (_in2Len[0] * 28), 4, _praIn[0].buf.pv);
   _praIn[0].buf.nLen = (28 * _in2Len[0]);
   for(_ii = 0, _seq_primIn2 = (char*)_praIn[0].buf.pv, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_primIn2 = (_seq_primIn2 + 28), _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_8(_al, (_praIn + 1), _ppraIn, (_praROut + 0), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn2, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   _COPY(_primIn, 12, _rout3Len, 0, 4);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 4), 4, _praIn[1].buf.pv);
   _praIn[1].buf.nLen = (4 * _rout3Len[0]);
   _ALLOCATE(_nErr, _al, (_rout3Len[0] * 24), 4, _praROut[0].buf.pv);
   _praROut[0].buf.nLen = (24 * _rout3Len[0]);
   for(_ii = 0, _seq_primIn3 = (char*)_praIn[1].buf.pv, _seq_primROut3 = (char*)_praROut[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primIn3 = (_seq_primIn3 + 4), _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_pack_6(_al, (_praIn + 2), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn3, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _TRY(_nErr, _stub_pack_4(_al, (_praIn + 2), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, ((char*)_primIn + 16), ((char*)_primROut + 0), (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5]))));
   _COPY(_primIn, 20, _in5Len, 0, 4);
   _ALLOCATE(_nErr, _al, (_in5Len[0] * 8), 4, _praIn[2].buf.pv);
   _praIn[2].buf.nLen = (8 * _in5Len[0]);
   for(_ii = 0, _seq_primIn5 = (char*)_praIn[2].buf.pv, _seq_nat5 = (char*)_in5[0];_ii < (int)_in5Len[0];++_ii, _seq_primIn5 = (_seq_primIn5 + 8), _seq_nat5 = (_seq_nat5 + SLIM_IFPTR32(12, 24)))
   {
      _TRY(_nErr, _stub_pack_10(_al, (_praIn + 3), _ppraIn, (_praROut + 1), _ppraROut, _praHIn, _ppraHIn, _praHROut, _ppraHROut, _seq_primIn5, 0, SLIM_IFPTR32((const hexagon_nn_execute_option*)&(((uint32_t*)_seq_nat5)[0]), (const hexagon_nn_execute_option*)&(((uint64_t*)_seq_nat5)[0]))));
   }
   _ASSERT(_nErr, (_numInH[0] + 0) <= 15);
   _ASSERT(_nErr, (_numROutH[0] + 0) <= 15);
   _TRY(_nErr, __QAIC_REMOTE(remote_handle64_invoke)(_handle, REMOTE_SCALARS_MAKEX(0, _mid, (_numIn[0] + 1), (_numROut[0] + 1), (_numInH[0] + 0), (_numROutH[0] + 0)), _pra));
   for(_ii = 0, _seq_nat2 = (char*)_in2[0];_ii < (int)_in2Len[0];++_ii, _seq_nat2 = (_seq_nat2 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_6((_praROutPost + 0), _ppraROutPost, 0, SLIM_IFPTR32((const hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat2)[0]), (const hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat2)[0]))));
   }
   for(_ii = 0, _seq_primROut3 = (char*)_praROutPost[0].buf.pv, _seq_nat3 = (char*)_rout3[0];_ii < (int)_rout3Len[0];++_ii, _seq_primROut3 = (_seq_primROut3 + 24), _seq_nat3 = (_seq_nat3 + SLIM_IFPTR32(32, 40)))
   {
      _TRY(_nErr, _stub_unpack_5((_praROutPost + 1), _ppraROutPost, _seq_primROut3, SLIM_IFPTR32((hexagon_nn_tensordef*)&(((uint32_t*)_seq_nat3)[0]), (hexagon_nn_tensordef*)&(((uint64_t*)_seq_nat3)[0]))));
   }
   _TRY(_nErr, _stub_unpack_3((_praROutPost + 1), _ppraROutPost, ((char*)_primROut + 0), (hexagon_nn_execute_result*)&(((uint32_t*)_rout4)[0]), SLIM_IFPTR32((unsigned char**)&(((uint32_t*)_rout4)[1]), (unsigned char**)&(((uint64_t*)_rout4)[1])), SLIM_IFPTR32((int*)&(((uint32_t*)_rout4)[2]), (int*)&(((uint32_t*)_rout4)[4])), SLIM_IFPTR32((unsigned int*)&(((uint32_t*)_rout4)[3]), (unsigned int*)&(((uint32_t*)_rout4)[5]))));
   for(_ii = 0, _seq_nat5 = (char*)_in5[0];_ii < (int)_in5Len[0];++_ii, _seq_nat5 = (_seq_nat5 + SLIM_IFPTR32(12, 24)))
   {
      _TRY(_nErr, _stub_unpack_7((_praROutPost + 1), _ppraROutPost, 0, SLIM_IFPTR32((const hexagon_nn_execute_option*)&(((uint32_t*)_seq_nat5)[0]), (const hexagon_nn_execute_option*)&(((uint64_t*)_seq_nat5)[0]))));
   }
   _CATCH(_nErr) {}
   _allocator_deinit(_al);
   return _nErr;
}
__QAIC_STUB_EXPORT int __QAIC_STUB(hexagon_nn_domains_execute_with_option)(remote_handle64 _handle, hexagon_nn_nn_id id, const hexagon_nn_tensordef* inputs, int inputsLen, hexagon_nn_tensordef* outputs, int outputsLen, hexagon_nn_execute_info* execute_info, const hexagon_nn_execute_option* in_options, int in_optionsLen) __QAIC_STUB_ATTRIBUTE {
   uint32_t _mid = 47;
   return _stub_method_42(_handle, 31, &_mid, (hexagon_nn_nn_id*)&id, (const hexagon_nn_tensordef**)&inputs, (int*)&inputsLen, (hexagon_nn_tensordef**)&outputs, (int*)&outputsLen, (hexagon_nn_execute_info*)execute_info, (const hexagon_nn_execute_option**)&in_options, (int*)&in_optionsLen);
}
#ifdef __cplusplus
}
#endif
#endif //_HEXAGON_NN_DOMAINS_STUB_H
